@@ -69,7 +69,7 @@ def d3graph(adjmat, df=None, node_name=None, node_color='#000080', node_color_ed
         * 0: Weighted approach using edge weights in the adjadancy matrix. Weights are normalized between the edge_distance_minmax
         * 80: Constant edge distance
 
-    NETWORK BEHAVOIR SETTINGS
+    NETWORK BEHAVIOR SETTINGS
     --------------------------
     collision : float, (default: 0.5)
         Nodes wants to prevent a collision. The higher the number, the more collisions are prevented.
@@ -181,7 +181,7 @@ def d3graph(adjmat, df=None, node_name=None, node_color='#000080', node_color_ed
     # Make node configurations
     df = _node_config(df, node_name, node_color, node_size, node_size_edge, node_color_edge, adjmat=adjmat, cmap=config['cmap'])
     # Create dataframe from co-occurence matrix
-    [G, df] = adjmat2G(adjmat, df, config['edge_distance_minmax'][0], config['edge_distance_minmax'][1], config['edge_width'])
+    G, df = adjmat2G(adjmat, df, config['edge_distance_minmax'][0], config['edge_distance_minmax'][1], config['edge_width'])
     # Make slider
     [min_slider, max_slider] = _setup_slider(G, slider=slider)
     config['min_slider'] = min_slider
@@ -193,9 +193,7 @@ def d3graph(adjmat, df=None, node_name=None, node_color='#000080', node_color_ed
     # Create html with json file embedded
     _write_index_html(config, json_data)
     # Final
-    out = dict()
-    out['G'] = G
-    out['path'] = config['path'] + 'index.html'
+    out = {'G': G, 'path':config['path'] + 'index.html'}
     # Open the webbrowser
     if config['showfig']: webbrowser.open(os.path.abspath(out['path']), new=2)
     # Return
@@ -273,7 +271,7 @@ def _write_index_html(config, json_data):
     jinja_env = Environment(loader=PackageLoader(package_name=__name__, package_path='d3js') )
     index_template = jinja_env.get_template('index.html.j2')
     index_file = Path(config['savepath'])
-    print('Writing %s' % index_file.absolute())
+    print('[d3graph] >Writing %s' % index_file.absolute())
     index_file.write_text(index_template.render(content))
 
 
@@ -366,8 +364,8 @@ def _node_config(df, node_name, node_color, node_size, node_size_edge, node_colo
     df['node_color_edge']=node_color_edge
     # Make strings of the identifiers
     df.index=df.index.astype(str)
-    df.columns=df.columns.str.replace(' ', '_', regex=True)
-    df.columns=df.columns.str.replace('.', '_', regex=True)
+    # df.index=df.index.str.replace(' ', '_', regex=True)
+    # df.columns=df.columns.str.replace(' ', '_', regex=True)
 
     return(df)
 
@@ -553,11 +551,112 @@ def _do_checks(adjmat):
 # %% Remov special characters from column names
 def _remove_special_chars(adjmat, verbose=3):
     if verbose>=3: print('[d3graph] >Removing special chars and replacing with "_"')
-    columns=adjmat.columns.values.astype(str)
-    adjmat.columns = list(map(lambda x: unicodedata.normalize('NFD', x).encode('ascii', 'ignore').decode("utf-8").replace(' ','_'), columns))
+    adjmat.columns = list(map(lambda x: unicodedata.normalize('NFD', x).encode('ascii', 'ignore').decode("utf-8").replace(' ','_'), adjmat.columns.values.astype(str)))
+    adjmat.index = list(map(lambda x: unicodedata.normalize('NFD', x).encode('ascii', 'ignore').decode("utf-8").replace(' ','_'), adjmat.index.values.astype(str)))
     return adjmat
 
 
+# %%  Convert adjacency matrix to vector
+def vec2adjmat(source, target, weight=None, symmetric=True):
+    """Convert source and target into adjacency matrix.
+
+    Parameters
+    ----------
+    source : list
+        The source node.
+    target : list
+        The target node.
+    weight : list of int
+        The Weights between the source-target values
+    symmetric : bool, optional
+        Make the adjacency matrix symmetric with the same number of rows as columns. The default is True.
+
+    Returns
+    -------
+    pd.DataFrame
+        adjacency matrix.
+    
+    Examples
+    --------
+    >>> source=['Cloudy','Cloudy','Sprinkler','Rain']
+    >>> target=['Sprinkler','Rain','Wet_Grass','Wet_Grass']
+    >>> vec2adjmat(source, target)
+    >>> 
+    >>> weight=[1,2,1,3]
+    >>> vec2adjmat(source, target, weight=weight)
+
+    """
+    if len(source)!=len(target): raise Exception('[d3graph] >Source and Target should have equal elements.')
+    if weight is None: weight = [1]*len(source)
+    
+    df = pd.DataFrame(np.c_[source, target], columns=['source','target'])
+    # Make adjacency matrix
+    adjmat = pd.crosstab(df['source'], df['target'], values=weight, aggfunc='sum').fillna(0)
+    # Get all unique nodes
+    nodes = np.unique(list(adjmat.columns.values)+list(adjmat.index.values))
+    # nodes = np.unique(np.c_[adjmat.columns.values, adjmat.index.values].flatten())
+
+    # Make the adjacency matrix symmetric
+    if symmetric:
+        # Add missing columns
+        node_columns = np.setdiff1d(nodes, adjmat.columns.values)
+        for node in node_columns:
+            adjmat[node]=0
+
+        # Add missing rows
+        node_rows = np.setdiff1d(nodes, adjmat.index.values)
+        adjmat=adjmat.T
+        for node in node_rows:
+            adjmat[node]=0
+        adjmat=adjmat.T
+
+        # Sort to make ordering of columns and rows similar
+        [IA, IB] = ismember(adjmat.columns.values, adjmat.index.values)
+        adjmat = adjmat.iloc[IB,:]
+        adjmat.index.name='source'
+        adjmat.columns.name='target'
+
+    return(adjmat)
+
+
+# %%  Convert adjacency matrix to vector
+def adjmat2vec(adjmat, min_weight=1):
+    """Convert adjacency matrix into vector with source and target.
+
+    Parameters
+    ----------
+    adjmat : pd.DataFrame()
+        Adjacency matrix.
+
+    min_weight : float
+        edges are returned with a minimum weight.
+
+    Returns
+    -------
+    pd.DataFrame()
+        nodes that are connected based on source and target
+
+    Examples
+    --------
+    >>> source=['Cloudy','Cloudy','Sprinkler','Rain']
+    >>> target=['Sprinkler','Rain','Wet_Grass','Wet_Grass']
+    >>> adjmat = vec2adjmat(source, target)
+    >>> vector = adjmat2vec(adjmat)
+
+    """
+    # Convert adjacency matrix into vector
+    adjmat = adjmat.stack().reset_index()
+    # Set columns
+    adjmat.columns = ['source', 'target', 'weight']
+    # Remove self loops and no-connected edges
+    Iloc1 = adjmat['source']!=adjmat['target']
+    Iloc2 = adjmat['weight']>=min_weight
+    Iloc = Iloc1 & Iloc2
+    # Take only connected nodes
+    adjmat = adjmat.loc[Iloc,:]
+    adjmat.reset_index(drop=True, inplace=True)
+    return(adjmat)
+
 # %% Main
 if __name__ == '__main__':
     d3graph(sys.argv[1:])
